@@ -26,6 +26,7 @@ from lino_xl.lib.cal.roles import CalendarReader
 from lino_xl.lib.votes.roles import VotesStaff, VotesUser
 from lino_xl.lib.products.roles import ProductsStaff
 from lino_xl.lib.ledger.roles import LedgerStaff
+from lino_xl.lib.orders.roles import OrdersUser, OrdersStaff
 
 from lino.modlib.users.choicelists import UserTypes
 
@@ -55,7 +56,9 @@ class Developer(Contributor, Expert, ContactsUser, Triager, ExcerptsStaff, Comme
     pass
 
 
-class SiteAdmin(SiteAdmin, Developer, OfficeStaff, VotesStaff, ContactsStaff, CommentsStaff, ProductsStaff, LedgerStaff):
+class SiteAdmin(
+    SiteAdmin, Developer, OfficeStaff, VotesStaff, ContactsStaff,
+    CommentsStaff, ProductsStaff, LedgerStaff, OrdersStaff):
     """
     Can do everything.
     """
